@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,7 +11,7 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
@@ -31,6 +31,25 @@ import string
 import hypothesis._strategies as st
 
 
+@st.defines_strategy_with_reusable_values
+def urls():
+    """A strategy for :rfc:`3986`, generating http/https URLs."""
+
+    def url_encode(s):
+        safe_chars = set(string.ascii_letters + string.digits + "$-_.+!*'(),")
+        return "".join(c if c in safe_chars else "%%%02X" % ord(c) for c in s)
+
+    schemes = st.sampled_from(["http", "https"])
+    ports = st.integers(min_value=0, max_value=2 ** 16 - 1).map(":{}".format)
+    paths = st.lists(st.text(string.printable).map(url_encode)).map(
+        lambda path: "/".join([""] + path)
+    )
+
+    return st.builds(
+        "{}://{}{}{}".format, schemes, domains(), st.one_of(st.just(""), ports), paths
+    )
+
+
 @st.defines_strategy_with_reusable_values
 def domains():
     """A strategy for :rfc:`1035` fully qualified domain names."""
